@@ -12,7 +12,7 @@ class FakeDate(real_date):
     date_to_freeze = None
 
     def __init__(self, *args, **kwargs):
-        return super(FakeDate, self).__init__(*args, **kwargs)
+        return real_date.__init__(*args, **kwargs)
 
     def __add__(self, other):
         result = super(FakeDate, self).__add__(other)
@@ -24,7 +24,10 @@ class FakeDate(real_date):
         result = super(FakeDate, self).__sub__(other)
         if result is NotImplemented:
             return result
-        return date_to_fakedate(result)
+        if isinstance(result, real_date):
+            return date_to_fakedate(result)
+        else:
+            return result
 
     @classmethod
     def today(cls):
@@ -41,7 +44,7 @@ class FakeDatetime(real_datetime, FakeDate):
     tz_offset = None
 
     def __init__(self, *args, **kwargs):
-        return super(FakeDatetime, self).__init__(*args, **kwargs)
+        return real_datetime.__init__(*args, **kwargs)
 
     def __add__(self, other):
         result = super(FakeDatetime, self).__add__(other)
@@ -53,7 +56,10 @@ class FakeDatetime(real_datetime, FakeDate):
         result = super(FakeDatetime, self).__sub__(other)
         if result is NotImplemented:
             return result
-        return datetime_to_fakedatetime(result)
+        if isinstance(result, real_datetime):
+            return datetime_to_fakedatetime(result)
+        else:
+            return result
 
     @classmethod
     def now(cls):
